@@ -16,7 +16,6 @@ import os
 import time
 
 from google.cloud import container_v1
-from google.cloud.container_v1.proto import cluster_service_pb2
 
 
 class TestSystemClusterManager(object):
@@ -24,6 +23,6 @@ class TestSystemClusterManager(object):
         project_id = os.environ["PROJECT_ID"]
 
         client = container_v1.ClusterManagerClient()
-        project_id_2 = project_id
-        zone = "us-central1-a"
-        response = client.list_clusters(project_id_2, zone)
+        response = client.list_clusters(
+            request={"project_id": os.environ["PROJECT_ID"], "zone": "us-central1-a"}
+        )
